@@ -786,7 +786,28 @@ def psv(cfg, images, intrinsics, extrinsics, depth_hypos):
     return pairwise_psv
 
 
-def homography_warp_var(features, ref_in, src_in, ref_ex, src_ex, depth_hypos):
+def homogeneous_pixel_coords(batch_size, height, width, device):
+    with torch.no_grad():
+        y, x = torch.meshgrid(
+            [
+                torch.arange(
+                    0, height, dtype=torch.float32, device=device
+                ),
+                torch.arange(
+                    0, width, dtype=torch.float32, device=device
+                ),
+            ],
+            indexing="ij",
+        )
+        y, x = y.contiguous(), x.contiguous()
+        y, x = y.view(height * width), x.view(height * width)
+        xyz = torch.stack((x, y, torch.ones_like(x)))  # [3, H*W]
+        xyz = torch.unsqueeze(xyz, 0).repeat(batch_size, 1, 1)  # [B, 3, H*W]
+    return xyz
+
+
+def homography_warp_var(features, intrinsics, extrinsics, depth_hypos, reference_index,
+):
     """Performs homography warping to create a Plane Sweeping Volume (PSV).
     Parameters:
         features: Feature maps to be warped into a PSV.
@@ -803,78 +824,66 @@ def homography_warp_var(features, ref_in, src_in, ref_ex, src_ex, depth_hypos):
     depth_hypos = depth_hypos.squeeze(1)
     _, planes, _, _ = depth_hypos.shape
 
-    B, fCH, H, W = features[0].shape
+    batch_size, num_views, channels, height, width = features.shape
     num_depth = depth_hypos.shape[1]
-    nSrc = len(features) - 1
 
-    vis_weight_list = []
-    ref_volume = features[0].unsqueeze(2).repeat(1, 1, num_depth, 1, 1)
+    ref_volume = features[:,reference_index].unsqueeze(2).repeat(1, 1, num_depth, 1, 1)
+    ref_in = intrinsics[:, reference_index]
+    ref_ex = extrinsics[:, reference_index]
+    ref_proj = torch.matmul(ref_in, ref_ex[:, 0:3, :])
+    last = torch.tensor([[[0, 0, 0, 1.0]]]).repeat(batch_size, 1, 1).to(features.device)
+    ref_proj = torch.cat((ref_proj, last), 1)
 
-    cost_volume = torch.zeros((nSrc + 1, B, fCH, planes, H, W)).to(features[0])
-    cost_volume[0] = ref_volume
-    reweight_sum = None
-    for src in range(nSrc):
+    xyz = homogeneous_pixel_coords(batch_size, height, width, features.device)
+
+    # maintain rolling variance
+    cost_sum = torch.zeros_like(ref_volume)
+    cost_sq_sum = torch.zeros((batch_size, channels, planes, height, width)).to(features)
+    cost_sum = cost_sum + ref_volume
+    cost_sq_sum = cost_sq_sum + torch.pow(ref_volume, 2)
+
+    for v in range(num_views):
+        if v == reference_index:
+            continue
         with torch.no_grad():
-            with autocast(enabled=False):
-                src_proj = torch.matmul(src_in[:, src, :, :], src_ex[:, src, 0:3, :])
-                ref_proj = torch.matmul(ref_in, ref_ex[:, 0:3, :])
-                last = torch.tensor([[[0, 0, 0, 1.0]]]).repeat(len(src_in), 1, 1).cuda()
-                src_proj = torch.cat((src_proj, last), 1)
-                ref_proj = torch.cat((ref_proj, last), 1)
+            src_proj = torch.matmul(intrinsics[:, v, :, :], extrinsics[:, v, 0:3, :])
+            src_proj = torch.cat((src_proj, last), 1)
 
-                proj = torch.matmul(src_proj, torch.inverse(ref_proj))
-                rot = proj[:, :3, :3]  # [B,3,3]
-                trans = proj[:, :3, 3:4]  # [B,3,1]
+            proj = torch.matmul(src_proj, torch.inverse(ref_proj))
+            rot = proj[:, :3, :3]  # [B,3,3]
+            trans = proj[:, :3, 3:4]  # [B,3,1]
 
-                y, x = torch.meshgrid(
-                    [
-                        torch.arange(
-                            0, H, dtype=torch.float32, device=ref_volume.device
-                        ),
-                        torch.arange(
-                            0, W, dtype=torch.float32, device=ref_volume.device
-                        ),
-                    ],
-                    indexing="ij",
-                )
-                y, x = y.contiguous(), x.contiguous()
-                y, x = y.view(H * W), x.view(H * W)
-                xyz = torch.stack((x, y, torch.ones_like(x)))  # [3, H*W]
-                xyz = torch.unsqueeze(xyz, 0).repeat(B, 1, 1)  # [B, 3, H*W]
-                rot_xyz = torch.matmul(rot, xyz)  # [B, 3, H*W]
+            rot_xyz = torch.matmul(rot, xyz)  # [B, 3, H*W]
+            rot_depth_xyz = rot_xyz.unsqueeze(2).repeat(
+                1, 1, num_depth, 1
+            ) * depth_hypos.view(
+                batch_size, 1, num_depth, height * width
+            )  # [B, 3, Ndepth, H*W]
+            proj_xyz = rot_depth_xyz + trans.view(batch_size, 3, 1, 1)  # [B, 3, Ndepth, H*W]
+            proj_xy = (
+                proj_xyz[:, :2, :, :] / proj_xyz[:, 2:3, :, :]
+            )  # [B, 2, Ndepth, H*W]
+            proj_x_normalized = proj_xy[:, 0, :, :] / ((width - 1) / 2) - 1
+            proj_y_normalized = proj_xy[:, 1, :, :] / ((height - 1) / 2) - 1
+            proj_xy = torch.stack(
+                (proj_x_normalized, proj_y_normalized), dim=3
+            )  # [B, Ndepth, H*W, 2]
+            grid = proj_xy
+        grid = grid.to(ref_volume)
 
-                rot_depth_xyz = rot_xyz.unsqueeze(2).repeat(
-                    1, 1, num_depth, 1
-                ) * depth_hypos.view(
-                    B, 1, num_depth, H * W
-                )  # [B, 3, Ndepth, H*W]
-                proj_xyz = rot_depth_xyz + trans.view(B, 3, 1, 1)  # [B, 3, Ndepth, H*W]
-                proj_xy = (
-                    proj_xyz[:, :2, :, :] / proj_xyz[:, 2:3, :, :]
-                )  # [B, 2, Ndepth, H*W]
-                proj_x_normalized = proj_xy[:, 0, :, :] / ((W - 1) / 2) - 1
-                proj_y_normalized = proj_xy[:, 1, :, :] / ((H - 1) / 2) - 1
-                proj_xy = torch.stack(
-                    (proj_x_normalized, proj_y_normalized), dim=3
-                )  # [B, Ndepth, H*W, 2]
-                grid = proj_xy
-
-        grid = grid.type(ref_volume.dtype)
         warped_src_fea = F.grid_sample(
-            features[src + 1],
-            grid.view(B, num_depth * H, W, 2),
+            features[:,v],
+            grid.view(batch_size, num_depth * height, width, 2),
             mode="bilinear",
             padding_mode="zeros",
             align_corners=False,
         )
-        cost_volume[src + 1] = warped_src_fea.view(B, fCH, num_depth, H, W)
+        warped_src_fea = warped_src_fea.view(batch_size, channels, num_depth, height, width)
 
-        torch.cuda.empty_cache()
+        cost_sum = cost_sum + warped_src_fea
+        cost_sq_sum = cost_sq_sum + torch.pow(warped_src_fea, 2)
 
-    cost_volume = torch.var(cost_volume, dim=0)
-    B, C, D, H, W = cost_volume.shape
-
-    return cost_volume
+    return (cost_sq_sum - torch.pow(cost_sum, 2)/num_views) / (num_views-1)
 
 
 def homography_warp(
@@ -1219,6 +1228,43 @@ def rigid_transform(points: NDArray[Any], transform: NDArray[Any]) -> NDArray[An
 
     return np.matmul(transform, homog_coords)[:, :3, 0]
 
+def project_points(points: torch.Tensor, depth_map: torch.Tensor, P: torch.Tensor, K: torch.Tensor) -> torch.Tensor:
+    """Projects a depth map into a list of 3D points
+
+    Parameters:
+        depth: Input depth map to project.
+        cam: Camera parameters for input depth map.
+
+    Returns:
+        A float Tensor of 3D points corresponding to the projected depth values.
+    """
+    _, _, height, width = depth_map.shape
+    batch_size, N, _ = points.shape
+    K_aug = torch.zeros_like(P)
+    K_aug[:,:3,:3] = K[:,:3,:3]
+    K_aug[:,3,:] = torch.tensor([0,0,0,1])
+
+    # construct projection from camera matrices
+    projection = torch.matmul(K_aug, P).to(torch.float32)
+    projection = projection.reshape(batch_size, 1,  4, 4).repeat(1,N,1,1)
+
+    points = torch.cat((points, torch.ones_like(points[:,:,0:1])), dim=2).unsqueeze(-1)
+    pixels = torch.matmul(projection, points)[:,:,:3,0]
+    pixels = pixels.div_(pixels[:,:,2:3])
+
+    proj_x_normalized = pixels[:, :, 0] / ((width - 1) / 2) - 1
+    proj_y_normalized = pixels[:, :, 1] / ((height - 1) / 2) - 1
+    grid = torch.stack((proj_x_normalized, proj_y_normalized), dim=2).to(torch.float32)
+
+    projected_depths = F.grid_sample(
+        depth_map,
+        grid.view(batch_size, height,        ## Return
+ width, 2),
+        mode="bilinear",
+        padding_mode="zeros",
+        align_corners=False,
+    )
+    return projected_depths.view(batch_size, 1, height, width)
 
 def project_depth_map(depth: torch.Tensor, P: torch.Tensor, K: torch.Tensor, mask: torch.Tensor | None = None) -> torch.Tensor:
     """Projects a depth map into a list of 3D points
@@ -1258,16 +1304,12 @@ def project_depth_map(depth: torch.Tensor, P: torch.Tensor, K: torch.Tensor, mas
     world_coords = world_coords + bwd_translation
     world_coords = torch.movedim(world_coords, 1, 2)
 
-    # filter world coordinates where depth is <= 0
-    depth = depth.squeeze(1)
-    filter_mask = depth > 0
-    
     # mask world points optionally
     if (mask != None):
-        filter_mask *= mask.reshape(batch_size, -1)
+        mask = mask.reshape(batch_size, -1)
+        world_coords = world_coords[mask].unsqueeze(0)
 
-    return world_coords[filter_mask].unsqueeze(0)
-    # return world_coords
+    return world_coords
 
 def project_depth_map_np(depth: NDArray[np.float32], P: NDArray[np.float32], K: NDArray[np.float32], mask: NDArray[np.float32] | None = None) -> NDArray[np.float32]:
     """Projects a depth map into a list of 3D points
